# -*- coding: utf-8 -*-
"""
Created on Wed Oct 21 18:48:07 2020

Github: https://github.com/tjczec01

@author: Travis J Czechorski

E-mail: tjczec01@gmail.com

"""

from chemsys import * 
import pkg_resources
from pkgutil import extend_path
__path__ = extend_path(__path__, __name__)
pkg_resources.declare_namespace(__name__)
